==> jc-1.4.0.tar.gz: java__5fcup/parse__5faction__5frow.h <==
// public class java_cup.parse_action_row

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b00ef94bca87cc20 java__5fcup_parse__5faction__5frow

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_parse__5faction__5frow_H_
#define _JC_java__5fcup_parse__5faction__5frow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java__5fcup_parse__5faction__5frow$sub_refs	_jc_java__5fcup_parse__5faction__5frow$sub_refs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$sub_nonrefs	_jc_java__5fcup_parse__5faction__5frow$sub_nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$refs	_jc_java__5fcup_parse__5faction__5frow$refs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$nonrefs	_jc_java__5fcup_parse__5faction__5frow$nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$object	_jc_java__5fcup_parse__5faction__5frow$object;

typedef struct _jc_java__5fcup_parse__5faction__5frow$fields_struct	_jc_java__5fcup_parse__5faction__5frow$fields_struct;
typedef const struct _jc_java__5fcup_parse__5faction__5frow$vmethods	_jc_java__5fcup_parse__5faction__5frow$vmethods;
typedef const struct _jc_java__5fcup_parse__5faction__5frow$vtable	_jc_java__5fcup_parse__5faction__5frow$vtable;
typedef const struct _jc_java__5fcup_parse__5faction__5frow$vtype	_jc_java__5fcup_parse__5faction__5frow$vtype;

// Class fields structure
struct _jc_java__5fcup_parse__5faction__5frow$fields_struct {
	_jc_int_array	*reduction__5fcount;
	jint	__5fsize;
};
extern _jc_java__5fcup_parse__5faction__5frow$fields_struct _jc_java__5fcup_parse__5faction__5frow$class_fields;

// Constructors
extern void _jc_java__5fcup_parse__5faction__5frow$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_parse__5faction__5frow$object *);

// Virtual methods
extern void _jc_java__5fcup_parse__5faction__5frow$method$compute__5fdefault$3f583230b347a173(_jc_env *, struct _jc_java__5fcup_parse__5faction__5frow$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_parse__5faction__5frow$method_info$compute__5fdefault$3f583230b347a173;

// Static methods
extern void _jc_java__5fcup_parse__5faction__5frow$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jint _jc_java__5fcup_parse__5faction__5frow$method$size$345df5220fc60ade(_jc_env *);

// Virtual methods structure
struct _jc_java__5fcup_parse__5faction__5frow$vmethods {
	void	(*compute__5fdefault$3f583230b347a173)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5frow$object *);
};

// Vtable
struct _jc_java__5fcup_parse__5faction__5frow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_parse__5faction__5frow$vmethods	java__5fcup_parse__5faction__5frow;
};

// Vtype
struct _jc_java__5fcup_parse__5faction__5frow$vtype {
	_jc_type			type;
	_jc_java__5fcup_parse__5faction__5frow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5frow$sub_refs {
	_jc_object_array	*under__5fterm;
};

// Reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5frow$refs {
    _jc_java__5fcup_parse__5faction__5frow$sub_refs	java__5fcup_parse__5faction__5frow;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5frow$sub_nonrefs {
	jint	default__5freduce;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5frow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_parse__5faction__5frow$sub_nonrefs	java__5fcup_parse__5faction__5frow;
};

// Object instance structure
struct _jc_java__5fcup_parse__5faction__5frow$object {
	_jc_java__5fcup_parse__5faction__5frow$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_parse__5faction__5frow$vtype	*vtype;
	_jc_java__5fcup_parse__5faction__5frow$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_parse__5faction__5frow$vtype _jc_java__5fcup_parse__5faction__5frow$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_parse__5faction__5frow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_parse__5faction__5frow$class_object;

#endif	/* _JC_java__5fcup_parse__5faction__5frow_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/parse__5faction__5frow.h <==
// public class java_cup.parse_action_row

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b00ef94bca87cc20 java__5fcup_parse__5faction__5frow

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_parse__5faction__5frow_H_
#define _JC_java__5fcup_parse__5faction__5frow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java__5fcup_parse__5faction__5frow$sub_refs	_jc_java__5fcup_parse__5faction__5frow$sub_refs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$sub_nonrefs	_jc_java__5fcup_parse__5faction__5frow$sub_nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$refs	_jc_java__5fcup_parse__5faction__5frow$refs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$nonrefs	_jc_java__5fcup_parse__5faction__5frow$nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5frow$object	_jc_java__5fcup_parse__5faction__5frow$object;

typedef struct _jc_java__5fcup_parse__5faction__5frow$fields_struct	_jc_java__5fcup_parse__5faction__5frow$fields_struct;
typedef const struct _jc_java__5fcup_parse__5faction__5frow$vmethods	_jc_java__5fcup_parse__5faction__5frow$vmethods;
typedef const struct _jc_java__5fcup_parse__5faction__5frow$vtable	_jc_java__5fcup_parse__5faction__5frow$vtable;
typedef const struct _jc_java__5fcup_parse__5faction__5frow$vtype	_jc_java__5fcup_parse__5faction__5frow$vtype;

// Class fields structure
struct _jc_java__5fcup_parse__5faction__5frow$fields_struct {
	_jc_int_array	*reduction__5fcount;
	jint	__5fsize;
};
extern _jc_java__5fcup_parse__5faction__5frow$fields_struct _jc_java__5fcup_parse__5faction__5frow$class_fields;

// Constructors
extern void _jc_java__5fcup_parse__5faction__5frow$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_parse__5faction__5frow$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java__5fcup_parse__5faction__5frow$method$compute__5fdefault$3f583230b347a173(_jc_env *, struct _jc_java__5fcup_parse__5faction__5frow$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_parse__5faction__5frow$method_info$compute__5fdefault$3f583230b347a173;

// Static methods
extern void _jc_java__5fcup_parse__5faction__5frow$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_parse__5faction__5frow$method$size$345df5220fc60ade(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_parse__5faction__5frow$vmethods {
	void	(*compute__5fdefault$3f583230b347a173)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5frow$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_parse__5faction__5frow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_parse__5faction__5frow$vmethods	java__5fcup_parse__5faction__5frow;
};

// Vtype
struct _jc_java__5fcup_parse__5faction__5frow$vtype {
	_jc_type			type;
	_jc_java__5fcup_parse__5faction__5frow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5frow$sub_refs {
	_jc_object_array	*under__5fterm;
};

// Reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5frow$refs {
    _jc_java__5fcup_parse__5faction__5frow$sub_refs	java__5fcup_parse__5faction__5frow;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5frow$sub_nonrefs {
	jint	default__5freduce;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5frow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_parse__5faction__5frow$sub_nonrefs	java__5fcup_parse__5faction__5frow;
};

// Object instance structure
struct _jc_java__5fcup_parse__5faction__5frow$object {
	_jc_java__5fcup_parse__5faction__5frow$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_parse__5faction__5frow$vtype	*vtype;
	_jc_java__5fcup_parse__5faction__5frow$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_parse__5faction__5frow$vtype _jc_java__5fcup_parse__5faction__5frow$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_parse__5faction__5frow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_parse__5faction__5frow$class_object;

#endif	/* _JC_java__5fcup_parse__5faction__5frow_H_ */
